EventSync

Trait EventSync 

pub trait EventSync:
    'static
    + Send
    + Sync { }
Available on crate feature sender only.
Event synchronization used by TracingEventSender.

Synchronization might be necessary in a multithreaded environments, where events may arrive from different threads out of order. This functionality is encapsulated in the (std-dependent) Synced implementation.

For single-threaded environments (e.g., WASM), there is the no-op () implementation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl EventSync for ()

Default implementation that does not perform any synchronization.

Implementors